Struct ClaimOnOom
pub struct ClaimOnOom(/* private fields */);Expand description
An out-of-memory handler that attempts to claim the
memory within the given Span upon OOM.
The contained span is then overwritten with an empty span.
If the span is empty or claim fails, allocation failure occurs.
Implementations
impl ClaimOnOom
impl ClaimOnOom